URL_API = 'https://leilookup.gleif.org/api/v1/leirecords?lei='
URL_LEVEL2_CONCAT_FILES\
    = 'https://leidata.gleif.org/api/v1/concatenated-files/rr/%date%/zip'

ATTR_DOLLAR_SIGN = '$'

ATTR_LEI = 'LEI'

ATTR_ENTITY_BUSINESS_REGISTER_ENTITY_ID = 'BusinessRegisterEntityID'
ATTR_ENTITY_ENTITY_STATUS = 'EntityStatus'
ATTR_ENTITY_LEGAL_FORM = 'LegalForm'
ATTR_ENTITY_LEGAL_JURISDICTION = 'LegalJurisdiction'
ATTR_ENTITY_LEGAL_NAME = 'LegalName'

ATTR_INITIAL_REGISTRATION_DATE = 'InitialRegistrationDate'
ATTR_LAST_UPDATE_DATE = 'LastUpdateDate'
ATTR_MANAGING_LOU = 'ManagingLOU'
ATTR_NEXT_RENEWAL_DATE = 'NextRenewalDate'
ATTR_REGISTRATION_STATUS = 'RegistrationStatus'
ATTR_VALIDATION_SOURCES = 'ValidationSources'

ATTR_ADDRESS_TYPE_HQ = 'HeadquartersAddress'
ATTR_ADDRESS_TYPE_LEGAL = 'LegalAddress'
ATTR_ADDRESS_CITY = 'City'
ATTR_ADDRESS_COUNTRY = 'Country'
ATTR_ADDRESS_LINE1 = 'Line1'
ATTR_ADDRESS_POSTAL_CODE = 'PostalCode'
ATTR_ADDRESS_REGION = 'Region'

ATTR_REGISTER = '@register'
ATTR_REGISTRATION = 'Registration'
ATTR_ENTITY = 'Entity'
